%define debug_package %{nil}

Name:           ocaml-camlidl
Version:        1.05
Release:        %mkrel 25
Summary:        Stub code generator and COM binding for OCaml
Group:          Development/OCaml
License:        QPL and LGPLv2 with exceptions
URL:            http://caml.inria.fr/pub/old_caml_site/camlidl/
Source0:        http://caml.inria.fr/pub/old_caml_site/distrib/bazar-ocaml/camlidl-%{version}.tar.gz
Source1:        http://caml.inria.fr/pub/old_caml_site/distrib/bazar-ocaml/camlidl-%{version}.doc.pdf

# Build the compiler into a native code program using ocamlopt.
Patch1:         camlidl-1.05-use-ocamlopt-for-compiler.patch
# Add 'make byte' and 'make install-byte' targets.
Patch2:         camlidl-1.05-bytecode.patch

BuildRequires:  ocaml-compiler

%description
CamlIDL is a stub code generator and COM binding for OCaml.

CamlIDL comprises two parts:

* A stub code generator that generates the C stub code required for
  the Caml/C interface, based on an MIDL specification. (MIDL stands
  for Microsoft's Interface Description Language; it looks like C
  header files with some extra annotations, plus a notion of object
  interfaces that look like C++ classes without inheritance.)

* A (currently small) library of functions and tools to import COM
  components in Caml applications, and export Caml code as COM
  components.


%package    devel
Summary:    Development files for %{name}
Group:      Development/OCaml
Requires:   %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%setup -q -n camlidl-%{version}
%patch1 -p1
%patch2 -p1
cp config/Makefile.unix config/Makefile

# compiler/ contains a module called 'Array' which conflicts with the
# OCaml stdlib module (although only when using ocamlopt for some
# reason).
mv compiler/array.ml compiler/idlarray.ml
mv compiler/array.mli compiler/idlarray.mli

perl -pi.bak -e 's/array/idlarray/g' \
  compiler/Makefile compiler/.depend
perl -pi.bak -e 's/Array(?!\d)/Idlarray/g' \
  compiler/*.ml

cp %{SOURCE1} .

# prevent if the META file appears in a future version
if [ -f META ]; then exit 1; fi
cat > META <<EOF
name = "camlidl"
version = "%{version}"
description = "Stub generator"
directory = "^"
archive(byte) = "com.cma"
archive(native) = "com.cmxa"
EOF

%build
make all OCAMLLIB=%{_libdir}/ocaml BINDIR=%{_bindir}

%install
install -d -m 755 %{buildroot}%{_libdir}/ocaml
install -d -m 755 %{buildroot}%{_libdir}/ocaml/caml
install -d -m 755 %{buildroot}%{_libdir}/ocaml/camlidl
install -d -m 755 %{buildroot}%{_bindir}

make OCAMLLIB=%{buildroot}%{_libdir}/ocaml \
     BINDIR=%{buildroot}%{_bindir} \
     install

install -m 644 META %{buildroot}%{_libdir}/ocaml/camlidl/

%files
%doc LICENSE
%dir %{_libdir}/ocaml/camlidl
%{_libdir}/ocaml/camlidl/META
%{_libdir}/ocaml/*.cmi
%{_libdir}/ocaml/*.cma
%{_bindir}/camlidl

%files devel
%doc LICENSE README Changes camlidl-%{version}.doc.pdf tests
%{_libdir}/ocaml/caml/*.h
%{_libdir}/ocaml/*.a
%{_libdir}/ocaml/*.cmxa


%changelog
* Fri Aug 21 2020 umeabot <umeabot> 1.05-25.mga8
+ Revision: 1617565
- Rebuild for new ocaml deps generator

* Fri Feb 28 2020 umeabot <umeabot> 1.05-24.mga8
+ Revision: 1551134
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 1.05-23.mga8
+ Revision: 1543452
- Mageia 8 Mass Rebuild

* Tue Oct 23 2018 tv <tv> 1.05-22.mga8
+ Revision: 1324033
- rebuild with ocaml-4.07.1

* Mon Oct 22 2018 pterjan <pterjan> 1.05-21.mga7
+ Revision: 1323727
- Rebuild for ocaml 4.07

* Sun Sep 23 2018 umeabot <umeabot> 1.05-20.mga7
+ Revision: 1299846
- Mageia 7 Mass Rebuild

* Sun Nov 26 2017 tv <tv> 1.05-19.mga7
+ Revision: 1179364
- fix build
- rebuild for new ocaml

* Mon Sep 26 2016 pterjan <pterjan> 1.05-18.mga6
+ Revision: 1056267
- Rebuild for fix in ocaml

* Fri Feb 12 2016 umeabot <umeabot> 1.05-17.mga6
+ Revision: 956312
- Mageia 6 Mass Rebuild

* Wed Oct 21 2015 tv <tv> 1.05-16.mga6
+ Revision: 893248
- rebuild with fixed deps

* Wed Oct 15 2014 umeabot <umeabot> 1.05-15.mga5
+ Revision: 739659
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 1.05-14.mga5
+ Revision: 725144
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 1.05-13.mga5
+ Revision: 683001
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.05-12.mga4
+ Revision: 508431
- Mageia 4 Mass Rebuild
+ blue_prawn <blue_prawn>
- s/Objective Caml/OCaml/ it was decided by the community to only use the name OCaml now

* Sat Jan 12 2013 umeabot <umeabot> 1.05-11.mga3
+ Revision: 361203
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 01 2012 blue_prawn <blue_prawn> 1.05-10.mga3
+ Revision: 301414
- build requires ocaml-compiler
- rebuild for ocaml-4.00.0
- rebuild for ocaml-4.00.0

* Sat Sep 29 2012 blue_prawn <blue_prawn> 1.05-8.mga3
+ Revision: 300048
- new rpm group for ocaml

* Mon Nov 21 2011 malo <malo> 1.05-7.mga2
+ Revision: 170183
- adding META from Godi
- spec clean-up

* Sat Apr 30 2011 pterjan <pterjan> 1.05-6.mga1
+ Revision: 93950
- Bump release higher than Mandriva

* Mon Mar 07 2011 saispo <saispo> 1.05-1.mga1
+ Revision: 66153
- imported package ocaml-camlidl

